resultSet.RankedResultSet

|  | ## Cheshire3 Object Model: Class RankedResultSet

Module resultSet :: Class RankedResultSet

## Class RankedResultSet
source code

Object Tree:

    baseObjects.ResultSet --+
                            |
                           RankedResultSet

Known Subclasses:
  SimpleResultSet

Instance Methods

_sumWeights(self, items, n)
_meanWeights(self, items, n)
_normWeights(self, items, n)
_cmbzWeights(self, a, b)
_nprvWeights(self, a, b)
_pivotWeights(self, a, b)
Inherited from `baseObjects.ResultSet`: `combine`, `retrieve`, `sort`

Class Variables

Inherited from `baseObjects.ResultSet`: `expires`, `id`, `index`, `maxWeight`, `minWeight`, `queryFragment`, `queryFreq`, `queryPositions`, `queryTerm`, `relevancy`, `termid`, `totalOccs`, `totalRecs`

Method Details

### _sumWeights(self, items, n) | source code

### _meanWeights(self, items, n) | source code

### _normWeights(self, items, n) | source code

### _cmbzWeights(self, a, b) | source code

### _nprvWeights(self, a, b) | source code

### _pivotWeights(self, a, b) | source code